# Pretty Print Me!

> Pretty print anything* to the terminal

[![Publish to PyPi](https://github.com/NicholasSynovic/pp-me/actions/workflows/pypi.yml/badge.svg)](https://github.com/NicholasSynovic/pp-me/actions/workflows/pypi.yml)

## Table of Contents

- [Pretty Print Me!](#pretty-print-me)
  - [Table of Contents](#table-of-contents)
  - [About](#about)
  - [Currently supported formats](#currently-supported-formats)
  - [How to Install](#how-to-install)
  - [How to Run](#how-to-run)

## About

Python module to pretty print a variety of formats to the terminal.

## Currently supported formats

- `.json`

## How to Install

0. Have `Python 3.9.6 +` installed
1. `pip install pp-me`

## How to Run

0. `pp-me -h` to display all options
1. Get silly with it
